<?php
/**
 * Epic Review FrontendAjax
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review;

use Jeg\Element\Element;

/**
 * Class FrontendAjax
 *
 * @package Epic\Review
 */
class FrontendAjax {
	/**
	 * FrontendAjax instance variable
	 *
	 * @var FrontendAjax
	 */
	private static $instance;

	/**
	 * Ajax request endpoint
	 *
	 * @var string
	 */
	private $endpoint = 'ajax-request';

	/**
	 * FrontendAjax Constructor.
	 */
	private function __construct() {
		if ( ! is_admin() ) {
			add_action( 'wp_head', array( $this, 'frontend_ajax_script' ), 1 );
			add_action( 'parse_request', array( $this, 'ajax_parse_request' ) );
			add_filter( 'query_vars', array( $this, 'ajax_query_vars' ) );
		}
	}

	/**
	 * Instance function
	 *
	 * @return FrontendAjax
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Ajax Query Variables
	 *
	 * @param array $vars .
	 *
	 * @return array
	 */
	public function ajax_query_vars( $vars ) {
		$vars[] = $this->endpoint;
		$vars[] = 'action';

		return $vars;
	}

	/**
	 * Check if doing ajax
	 *
	 * @return boolean
	 */
	public function is_doing_ajax() {
		return true;
	}

	/**
	 * Parse Ajax Requests
	 *
	 * @param object $wp .
	 */
	public function ajax_parse_request( $wp ) {
		if ( array_key_exists( $this->endpoint, $wp->query_vars ) ) {
			add_filter( 'wp_doing_ajax', array( $this, 'is_doing_ajax' ) );

			$action = $wp->query_vars['action'];

			switch ( $action ) {
				case 'review_search_handler':
					$manager      = Element::instance()->manager;
					$element_id   = 'epic_review_search';
					$element_attr = wp_unslash( $_POST['element_attr'] );
					$options      = json_decode( $element_attr );
					$attr         = [];

					foreach ( $options as $key => $value ) {
						$attr[ $key ] = $value;
					}

					$view   = $manager->get_element_view( $element_id );
					$output = $view->build_result( $attr );
					sanitize_review( $output );

					break;
			}

			do_action( 'epic_ajax_' . $action );

			exit;
		}
	}


	/**
	 * Set Frontend Ajax Variable
	 */
	public function frontend_ajax_script() {
		if ( ! is_admin() ) {
			?>
            <script type="text/javascript">var epic_ajax_url = '<?php sanitize_review( esc_url( $this->ajax_url() ) ); ?>'</script>
			<?php
		}
	}

	/**
	 * Frontend Ajax URL
	 */
	public function ajax_url() {
		return add_query_arg( array( $this->endpoint => 'epic_review' ), esc_url( home_url( '/' ) ) );
	}
}
