<?php
/**
 * Epic Review Backend
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Data;

/**
 * Class Backend
 *
 * @package Epic\Review\Data
 */
class Backend {
	/**
	 * Var Backend
	 *
	 * @var Backend
	 */
	private static $instance;

	/**
	 * Backend constructor.
	 */
	private function __construct() {
		if ( is_admin() ) {
			add_action( 'save_post', array( $this, 'save_post_review' ), 99 );
			add_filter( 'manage_edit-post_columns', array( $this, 'post_column' ), 9 );
			add_action( 'manage_posts_custom_column', array( $this, 'post_custom_column' ) );
		}
	}

	/**
	 * Backend instance function
	 *
	 * @return Backend
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Save Review Data
	 *
	 * @return boolean
	 */
	public function save_post_review() {
		global $post;

		if ( isset( $post->post_type ) && 'post' === $post->post_type ) {
			if ( isset( $_REQUEST['epic_review_metabox'] ) ) {
				update_post_meta( $post->ID, 'epic_review_enable', '1' );
				$ratingarray    = json_decode( urldecode( $_REQUEST['epic_review_metabox']['rating'] ) );
				$total          = 0;
				$numberofrating = 0;

				if ( $ratingarray ) {
					foreach ( $ratingarray as $rating ) {
						if ( 0 !== $rating->value && ! empty( $rating->label ) ) {
							$total += $rating->value;
							$numberofrating ++;
						}
					}

					if ( $numberofrating > 0 ) {
						$mean = $total / $numberofrating;
						$mean = round( $mean, 1 );
						update_post_meta( $post->ID, 'epic_rating_mean', $mean );
					}
				}
			}

			if ( isset( $_REQUEST['epic_review_metabox']['price'] ) ) {
				$pricearray = json_decode( urldecode( $_REQUEST['epic_review_metabox']['price'] ) );
				$total      = 0;

				$lowest  = 9999999999;
				$changed = false;
				foreach ( $pricearray as $price ) {
					if ( 0 !== $price->value || $price->value < $lowest ) {
						$lowest  = $price->value;
						$changed = true;
					}
					$total ++;
				}
				if ( $changed ) {
					update_post_meta( $post->ID, 'epic_price_lowest', $lowest );
				} else {
					update_post_meta( $post->ID, 'epic_price_lowest', 0 );
				}
			}
		}

		return true;
	}

	/**
	 * Post Column
	 *
	 * @param array $columns .
	 *
	 * @return mixed
	 */
	public function post_column( $columns ) {
		$columns['review'] = 'Post Type';

		return $columns;
	}

	/**
	 * Post Custom Column
	 *
	 * @param string $name .
	 */
	public function post_custom_column( $name ) {
		switch ( $name ) {
			case 'review':
				$output = '';
				$output = '<div class=\"epic-admin-review review-enabled\">' . esc_html__( 'Post Review', 'epic-review' ) . '</div>';
				if ( jeg_metabox( 'epic_review_metabox.enable_review', false ) ) {
					$output = '<div class=\"epic-admin-review review-enabled\">' . esc_html__( 'Post Review', 'epic-review' ) . '</div>';
				} else {
					$output = '<div class=\"epic-admin-review review-disabled\">' . esc_html__( 'Standard', 'epic-review' ) . '</div>';
				}
				sanitize_review( $output );
				break;
		}
	}
}
