<?php
/**
 * Epic Review Frontend
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Data;

/**
 * Class ReviewData
 *
 * @package Epic\Review\Data
 */
class PriceData {
	/**
	 * Post ID
	 *
	 * @var int
	 */
	private static $id;

	/**
	 * Widget
	 *
	 * @var boolean
	 */
	private static $widget;

	/**
	 * RatingData constructor.
	 *
	 * @param int $post_id .
	 */
	public function __construct( $post_id, $widget = false ) {
		self::$id     = $post_id;
		self::$widget = $widget;
	}

	/**
	 * Get Product Price Template
	 *
	 * @return string
	 */
	public function product_price() {
		$product_name = jeg_metabox( 'epic_review_metabox.name', null, self::$id );
		$prices       = jeg_metabox( 'epic_review_metabox.price', null, self::$id );
		$lowest_price = PHP_INT_MAX;
		$lowest_link  = '';
		$output       = '';

		if ( $prices ) {
			foreach ( $prices as $price ) {
				if ( ! empty( $price['shop'] ) && ! empty( $price['value'] ) ) {
					$price['value'] = floatval( $price['value'] );
					$icon           = '';

					if ( isset( $price['icon'] ) && $price['icon'] ) {
						$shop_icon = wp_get_attachment_image_src( $price['icon'], 'full' );
						$icon      = "<img class='store-icon' src={$shop_icon[0]} alt='{$price['shop']}'/>";
					};

					if ( ! empty( $price['link'] ) ) {
						$output .=
							'<li>
                                <a href="' . $price['link'] . '" target="_blank" class="storename">
                                    ' . $icon . $price['shop'] . '
                                </a>
                                <div class="priceinfo">
                                    <a href="' . $price['link'] . '" target="_blank" class="price">' . epic_review_get_price( $price['value'] ) . '</a>
                                    <a href="' . $price['link'] . '" target="_blank" class="productlink">' . esc_html__( 'Buy Now', 'epic-review' ) . '</a>
                                </div>
                            </li>';
					} else {
						$output .=
							'<li>
                                <a href="#" class="storename">
                                    ' . $icon . $price['shop'] . '
                                </a>
                                <div class="priceinfo">
                                    <a href="#" class="price">' . epic_review_get_price( $price['value'] ) . '</a>
                                </div>
                            </li>';
					}

					if ( $lowest_price > $price['value'] ) {
						$lowest_price = $price['value'];
						$lowest_link  = $price['link'];
					}

					update_post_meta( self::$id, 'epic_price_lowest', $lowest_price);
				}
			}
		}

		if ( ! empty( $output ) ) {
			$lowest_price = floatval( get_post_meta( self::$id, 'epic_price_lowest', true ) );

			if ( self::$widget ) {
				$output =
					'<div class="jeg_deals clearfix">
                        <div class="jeg_dealsheader clearfix">
                            <h3>' . esc_html__( 'Best Price', 'epic-review' ) . '</h3>
                            <strong class="price">' . epic_review_get_price( $lowest_price ) . '</strong>
                            <a href="' . $lowest_link . '" class="buy-now-deals clearfix">' .  esc_html__('Buy Now', 'epic-review', 'buy_now')  . '</a>
                        </div>
                        <div class="jeg_storeinfo">
                            <ul class="jeg_storelist">
                                ' . $output . '
                            </ul>
                        </div>
                    </div>';
			} else {
				$output =
					'<div class="jeg_deals clearfix">
                        <div class="jeg_dealsheader clearfix">
                            <div class="dealstitle">
                                <h3>' . sprintf( esc_html__( '%s DEALS', 'epic-review' ), $product_name ) . '</h3>
                                <p>' . esc_html__( 'We collect information from many stores for best price available', 'epic-review' ) . '</p>
                            </div>
                            <div class="bestprice">
                                <h4>' . esc_html__( 'Best Price', 'epic-review' ) . '</h4>
                                <strong class="price">' . epic_review_get_price( $lowest_price ) . '</strong>
                            </div>
                        </div>
                        <div class="jeg_storeinfo">
                            <ul class="jeg_storelist">
                                ' . $output . '
                            </ul>
                        </div>
                    </div>';
			}
		}

		return $output;
	}
}
