<?php
/**
 * Epic Review Frontend
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Data;

use Epic\Review\Data\SingleData;

/**
 * Class Single
 *
 * @package Epic\Review\Data
 */
class Single {
	/**
	 * Single
	 *
	 * @var Single
	 */
	private static $instance;

	/**
	 * Single constructor.
	 */
	private function __construct() {
		add_filter( 'the_content', array( $this, 'review_content' ), 10 );
		add_filter( 'the_content', array( $this, 'review_content_widget' ), 10 );
	}

	/**
	 * Instance Function
	 *
	 * @return Single
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Post Content
	 *
	 * @param string $content .
	 *
	 * @return string
	 */
	public function review_content( $content ) {
		if ( jeg_metabox( 'epic_review_metabox.enable_review', false ) ) {
			global $page, $numpages, $multipage;

			if ( $multipage ) {
				if ( $page === $numpages ) {
					return $this->render_review_content( $content );
				}
			} else {
				return $this->render_review_content( $content );
			}
		}

		return $content;
	}

	/**
	 * Render Post Review Content
	 *
	 * @param string $content .
	 *
	 * @return string
	 */
	public function render_review_content( $content ) {
		$post_review = $this->post_review();
		$content     = $content . $post_review;

		return $content;
	}

	/**
	 * Single Post Review
	 *
	 * @return string
	 */
	public function post_review() {
		$post_id     = get_the_ID();
		$single_data = new SingleData( 'single', $post_id );

		return $single_data->single_review_template();
	}

	/**
	 * Floating Review in Single
	 *
	 * @param string $content .
	 *
	 * @return string
	 */
	public function review_content_widget( $content ) {
		if ( jeg_metabox( 'epic_review_metabox.enable_review', false ) ) {
			if ( epic_get_option( 'price_float_position', 'right' ) === 'right' ) {
				$post_review_floating = $this->post_review_float();
				$content              = $post_review_floating . $content;
			}
		}

		return $content;
	}

	/**
	 * Floating Review Render
	 *
	 * @return string
	 */
	public function post_review_float() {
		$product_name = jeg_metabox( 'epic_review_metabox.name' );
		$prices       = jeg_metabox( 'epic_review_metabox.price' );
		$output       = '';

		if ( $prices ) {
			foreach ( $prices as $price ) {
				if ( ! empty( $price['shop'] ) && ! empty( $price['value'] ) ) {
					if ( ! empty( $price['link'] ) ) {
						$output .=
							'<li>
                                <a href="' . $price['link'] . '" target="_blank" class="storename">' . $price['shop'] . '</a>
                                <div class="priceinfo">
                                    <a href="' . $price['link'] . '" target="_blank" class="price">' . epic_review_get_price( $price['value'] ) . '</a>
                                    <a href="' . $price['link'] . '" target="_blank" class="productlink">' . esc_html__( 'VIEW', 'epic-review' ) . '</a>
                                </div>
                            </li>';
					} else {
						$output .=
							'<li>
                                <a href="#" class="storename">' . $price['shop'] . '</a>
                                <div class="priceinfo">
                                    <a href="#" class="price">' . epic_review_get_price( $price['value'] ) . '</a>
                                </div>
                            </li>';
					}
				}
			}
		}

		if ( ! empty( $output ) ) {
			$output =
				'<div class="jeg_deals jeg_deals_float clearfix">
                    <div class="jeg_dealsheader clearfix">
                        <div class="dealstitle">
                            <h3>' . sprintf( esc_html__( "%s DEALS", 'epic-review' ), $product_name ) . '</h3>
                        </div>
                    </div>
                    <div class="jeg_storeinfo">
                        <ul class="jeg_storelist">
                            ' . $output . '
                        </ul>
                    </div>
                </div>';
		}

		return $output;
	}
}
