<?php
/**
 * Epic Review Single Post Data
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Data;

use Epic\Review\Data\ProsConsData;
use Epic\Review\Data\RatingData;
use Epic\Review\Data\PriceData;

/**
 * Class SingleData
 *
 * @package Epic\Review\Data
 */
class SingleData {
	/**
	 * Post ID
	 *
	 * @var int
	 */
	private static $id;

	/**
	 * Array
	 *
	 * @var array
	 */
	private static $attr;

	/**
	 * String
	 *
	 * @var string
	 */
	private static $type;

	/**
	 * SingleData constructor.
	 *
	 * @param string $type .
	 * @param int    $post_id .
	 * @param array  $attr .
	 */
	public function __construct( $type, $post_id, $attr = null ) {
		self::$id   = $post_id;
		self::$attr = $attr;
		self::$type = $type;
	}

	/**
	 * Get Single Review Template
	 *
	 * @return string
	 */
	public function single_review_template( $widget = false ) {
		$rating_type         = jeg_metabox( 'epic_review_metabox.type', null, self::$id );
		$product_name        = jeg_metabox( 'epic_review_metabox.name', null, self::$id );
		$product_description = jeg_metabox( 'epic_review_metabox.summary', null, self::$id );
		$rating_data         = new RatingData( self::$id, $rating_type, $widget );
		$price_data          = new PriceData( self::$id, $widget );
		$proscons_data       = new ProsConsData( self::$id );
		$additional_style    = $rating_data->is_rating_empty() ? 'padding-left: 0' : '';

		if ( $widget ) {
			$output      = '<div class="jeg_review_widget">';
			$description = '<div class="jeg_review_summary ">' . esc_html( $product_description ) . '</div>';
		} else {
			$output      = '<div class="jeg_review_wrap">
             				<h2 class="jeg_review_title">' . esc_html( $product_name ) . '</h2>';
			$description = '<div class="desc" style="' . $additional_style . '">
			                    <p>' . esc_html( $product_description ) . '</p>
			                </div>';
		}

		if ( 'single' === self::$type ) {
			$output = $output . '<div class="jeg_reviewheader clearfix">'
									. $rating_data->get_review_score() . $description . '									
					            </div>
				                <div class="jeg_reviewdetail clearfix">
				                    ' . $proscons_data->product_pros() . '
				                    ' . $proscons_data->product_cons() . '
				                </div>'
								. $rating_data->get_review_bar()
								. $price_data->product_price()
								. '</div>';

		} elseif ( 'element' === self::$type ) {
			if ( self::$attr['review_show_rating'] ) {
				$output = $output . '<div class="jeg_reviewheader clearfix">' . $rating_data->get_review_score();
			}

			$output = $output . $description . '</div>';

			if ( self::$attr['review_show_pros_cons'] ) {
				if ( $widget ) {
					$output = $output . '<div class="jeg_review_procons">
					                    ' . $proscons_data->product_pros() . '
					                    ' . $proscons_data->product_cons() . '
					                </div>';
				} else {
					$output = $output . '<div class="jeg_reviewdetail clearfix">
					                    ' . $proscons_data->product_pros() . '
					                    ' . $proscons_data->product_cons() . '
					                </div>';
				}
			}

			if ( self::$attr['review_show_breakdown'] ) {
				$output = $output . $rating_data->get_review_bar();
			}

			if ( self::$attr['review_show_price'] ) {
				$output = $output . $price_data->product_price();
			}

			$output = $output . '</div>';
		}

		return $output;
	}
}
