<?php

namespace Epic\Review\Elements\Options;

use Jeg\Element\Elements\Elements_Option_Abstract;

/**
 * Class Review_Post_Option
 *
 * @package Epic\Review\Elements\Options
 */
class Review_Post_Option extends Elements_Option_Abstract {
	/**
	 * Compatible column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array( esc_html__( 'All Columns', 'epic-review' ) );
	}

	/**
	 * Set element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Epic - Review Post', 'epic-review' );
	}

	/**
	 * Set element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Epic Review', 'epic-review' );
	}

	/**
	 * Set page builder options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();
		unset( $this->options['column_width'] );
	}

	/**
	 * Set element options
	 */
	public function set_element_options() {
		$this->options['post_id_review']        = array(
			'type'        => 'select',
			'segment'     => 'general',
			'multiple'    => PHP_INT_MAX,
			'ajax'        => 'jeg_find_post',
			'options'     => 'jeg_get_post_option',
			'nonce'       => wp_create_nonce( 'jeg_find_post' ),
			'title'       => esc_html__( "Choose Post's Review", 'epic-review' ),
			'description' => wp_kses( __( "Enter post title or id to show it's review on this element. If you search by id, first type the post id and then press enter to add it on the list.", 'epic-review' ), wp_kses_allowed_html() ),
			'std'         => '',
		);
		$this->options['review_show_rating']    = array(
			'type'    => 'checkbox',
			'segment' => 'general',
			'title'   => esc_html__( 'Show Rating *', 'epic-review' ),
			'value'   => array( esc_html__( 'Show post review rating.', 'epic-review' ) => 'no' ),
		);
		$this->options['review_show_pros_cons'] = array(
			'type'    => 'checkbox',
			'segment' => 'general',
			'title'   => esc_html__( 'Show Pros and Cons *', 'epic-review' ),
			'value'   => array( esc_html__( 'Show Pros and Cons of post review.', 'epic-review' ) => 'no' ),
		);
		$this->options['review_show_breakdown'] = array(
			'type'    => 'checkbox',
			'segment' => 'general',
			'title'   => esc_html__( 'Show Review Breakdown *', 'epic-review' ),
			'value'   => array( esc_html__( 'Show post review breakdown.', 'epic-review' ) => 'no' ),
		);
		$this->options['review_show_price']     = array(
			'type'        => 'checkbox',
			'segment'     => 'general',
			'title'       => esc_html__( 'Show Price *', 'epic-review' ),
			'description' => esc_html__( '* Make sure the post you selected above is a review post and have the review attributes already set, otherwise it will show nothing even if checked.', 'epic-review' ),
			'value'       => array( esc_html__( 'Show post review prices.', 'epic-review' ) => 'no' ),
		);
	}

	/**
	 * Set option segments
	 */
	public function set_segments() {
		$this->segments['general'] = array(
			'name'     => esc_html__( 'General', 'epic-review' ),
			'priority' => 10,
		);
		$this->set_style_segment();
	}
}
