<?php

namespace Epic\Review\Elements\Options;

use Jeg\Element\Elements\Elements_Option_Abstract;

/**
 * Class Review_Search_Option
 *
 * @package Epic\Review\Elements\Options
 */
class Review_Search_Option extends Elements_Option_Abstract {
	/**
	 * Compatible column
	 *
	 * @return array
	 */
	public function compatible_column() {
		return array( esc_html__( 'All Columns', 'epic-review' ) );
	}

	/**
	 * Set element name
	 *
	 * @return string
	 */
	public function get_element_name() {
		return esc_html__( 'Epic - Review Search', 'epic-review' );
	}

	/**
	 * Set element category
	 *
	 * @return string
	 */
	public function get_category() {
		return esc_html__( 'Epic Review', 'epic-review' );
	}

	/**
	 * Set page builder options
	 */
	public function set_options() {
		$this->set_style_option();
		$this->set_element_options();

		unset( $this->options['column_width'] );
	}

	/**
	 * Set element options
	 */
	public function set_element_options() {

		$this->options['element_size'] = array(
			'type'        => 'select',
			'segment'     => 'general',
			'options'     => array(
				'bg' => 'Big',
				'md' => 'Medium',
				'sm' => 'Small',
			),
			'title'       => esc_html__( 'Choose Thumbnail Size', 'epic-review' ),
			'description' => esc_html__( 'Choose which size fit your page layout.', 'epic-review' ),
			'default'     => 'md',
		);

		$this->options['include_category'] = array(
			'type'        => 'select',
			'segment'     => 'general',
			'multiple'    => PHP_INT_MAX,
			'ajax'        => 'jeg_find_category',
			'options'     => 'jeg_get_category_option',
			'nonce'       => wp_create_nonce( 'jeg_find_category' ),
			'title'       => esc_html__( 'Choose filterable Category', 'epic-review' ),
			'description' => esc_html__( 'Choose which category you want to show on this module.', 'epic-review' ),
			'default'     => '',
		);

		$this->options['number_post'] = array(
			'type'        => 'slider',
			'segment'     => 'general',
			'title'       => esc_html__( 'Number of Post', 'epic-review' ),
			'description' => esc_html__( 'Show number of review on this module.', 'epic-review' ),
			'options'     => array(
				'min'     => 1,
				'max'     => 30,
				'step'    => 1,
			),
			'default' => 5,
		);

		$this->options['excerpt_length'] = array(
			'type'        => 'slider',
			'segment'     => 'general',
			'title'       => esc_html__( 'Excerpt Length', 'epic-review' ),
			'description' => esc_html__( 'Set word length of excerpt on post block.', 'epic-review' ),
			'group'       => esc_html__( 'Content Setting', 'epic-review' ),
			'options'     => array(
				'min'     => 0,
				'max'     => 200,
				'step'    => 1,
			),
			'default' => 20,
		);
	}

	/**
	 * Set option segments
	 */
	public function set_segments() {
		$this->segments['general'] = array(
			'name'     => esc_html__( 'General', 'epic-review' ),
			'priority' => 10,
		);
		$this->set_style_segment();
	}
}
