<?php
/**
 * Epic Review Element
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Elements\Views;

use Jeg\Element\Elements\Elements_View_Abstract;
use WP_Query;

/**
 * Class Review_Search_View
 *
 * @package Epic\Review\Elements\Views
 */
class Review_Search_View extends Elements_View_Abstract {
	/**
	 * Render Element
	 *
	 * @param array $attr .
	 * @param string $column_class .
	 *
	 * @return mixed|string
	 */
	public function render_element( $attr, $column_class ) {
		$select_category = $this->select_category( $attr );
		$select_sort     = $this->select_sort();

		$keyword = isset( $_REQUEST['keyword'] ) ? $_REQUEST['keyword'] : '';
		$page    = isset( $_REQUEST['page'] ) ? $_REQUEST['page'] : 1;
		$result  = $this->build_result( $attr );
		$loader  = $this->module_loader();

		$json_attr = wp_json_encode( $attr );
		$script    = "<script>var {$this->unique_id} = {$json_attr};</script>";

		$output =
			"<div class='jeg_review_search' data-id='{$this->unique_id}'>
                <form class='review-search-form' method='get'>
                    <div class='search-bar-wrapper'>
                        <input class='search_keyword' value='{$keyword}' type='text' placeholder='" . esc_html__( 'Search Review...', 'epic-review' ) . "' name='keyword' id='keyword'/>
                        <button class='search_review_button btn' type='submit'>
                            <i class=\"fa fa-search\"></i>
                        </button>
                    </div>
                    <div class='search-filter-wrapper'>
                        <div class='row'>
                            <div class='col-md-6'>
                                {$select_category}
                            </div>
                            <div class='col-md-6'>
                                {$select_sort}
                            </div>
                        </div>
                    </div>
                    <input type='hidden' name='element_attr' value='" . json_encode( $attr ) . "'/>
                    <input type='hidden' name='page' value='" . $page . "'/>
                    <input type='hidden' name='action' value='review_search_handler'/>
                    {$script}
                </form>
                <div class='jeg_review_search_result_wrapper'>
                    <div class='jeg_review_search_result_holder'>
                        {$result}
                    </div>
                    {$loader}
                </div>
            </div>";

		return $output;
	}

	/**
	 * Select Category
	 *
	 * @param array $attr .
	 *
	 * @return string
	 */
	public function select_category( $attr ) {
		$selected_category = isset( $_REQUEST['category'] ) ? $_REQUEST['category'] : '';
		$select_html       = '<option value="">' . esc_html__( 'All Category', 'epic-review' ) . '</option>';

		$categories = trim( $attr['include_category'] );
		if ( ! empty( $categories ) ) {
			$categories = explode( ',', $categories );
			$categories = is_array( $categories ) ? $categories : array( $categories );

			/*Need to cache category first "\epic\Util\Cache::get_categories();"*/

			foreach ( $categories as $category ) {
				$cat         = get_category( trim( $category ) );
				$selected    = ( $selected_category == $cat->term_id ) ? "selected='selected'" : '';
				$select_html .= "<option value='{$cat->term_id}' $selected>{$cat->name}</option>";
			}
		}

		return "<select name='category'>{$select_html}</select>";
	}

	/**
	 * Select Sort
	 *
	 * @return string
	 */
	public function select_sort() {
		$sort      = isset( $_REQUEST['sort'] ) ? $_REQUEST['sort'] : '';
		$sort_html = '';

		$sort_option = array(
			'date-desc'   => esc_html__( 'Newest First', 'epic-review' ),
			'date-asc'    => esc_html__( 'Oldest First', 'epic-review' ),
			'price-desc'  => esc_html__( 'Highest Price', 'epic-review' ),
			'price-asc'   => esc_html__( 'Lowest Price', 'epic-review' ),
			'rating-desc' => esc_html__( 'Highest Rating', 'epic-review' ),
			'rating-asc'  => esc_html__( 'Lowest Rating', 'epic-review' ),
		);

		foreach ( $sort_option as $key => $sorted ) {
			$selected  = ( $sort === $key ) ? "selected='selected'" : '';
			$sort_html .= "<option value='{$key}' $selected>{$sorted}</option>";
		}

		return "<select name='sort'>{$sort_html}</select>";
	}

	public function build_result( $attr = null ) {
		$keyword                = isset( $_REQUEST['keyword'] ) ? $_REQUEST['keyword'] : '';
		$page                   = isset( $_REQUEST['page'] ) ? $_REQUEST['page'] : 1;
		$sort                   = isset( $_REQUEST['sort'] ) ? $_REQUEST['sort'] : '';
		$category               = isset( $_REQUEST['category'] ) ? $_REQUEST['category'] : '';
		$review_elements        = '';
		$attr['number_post']    = $this->check_size( $attr['number_post'] );
		$attr['excerpt_length'] = $this->check_size( $attr['excerpt_length'] );

		$statement = array(
			's'              => esc_sql( $keyword ),
			'post_type'      => 'post',
			'post_status'    => array( 'publish' ),
			'posts_per_page' => $attr['number_post'],
			'paged'          => $page,
			'category__in'   => $category,
			'meta_query'     => array(
				'relation' => 'AND',
				array(
					'key'     => 'epic_review_metabox',
					'value'   => '"enable_review";s:1:"1"',
					'compare' => 'LIKE',
				),
			),
		);

		switch ( $sort ) {
			case 'date-desc':
				$statement['orderby'] = 'date';
				$statement['order']   = 'desc';
				break;
			case 'date-asc':
				$statement['orderby'] = 'date';
				$statement['order']   = 'asc';
				break;
			case 'price-desc':
				$statement['orderby']  = 'meta_value_num';
				$statement['meta_key'] = 'epic_price_lowest';
				$statement['order']    = 'desc';
				break;
			case 'price-asc':
				$statement['orderby']  = 'meta_value_num';
				$statement['meta_key'] = 'epic_price_lowest';
				$statement['order']    = 'asc';
				break;
			case 'rating-desc':
				$statement['orderby']  = 'meta_value_num';
				$statement['meta_key'] = 'epic_rating_mean';
				$statement['order']    = 'desc';
				break;
			case 'rating-asc':
				$statement['orderby']  = 'meta_value_num';
				$statement['meta_key'] = 'epic_rating_mean';
				$statement['order']    = 'asc';
				break;
		}

		$query = new WP_Query( $statement );

		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$review_elements .= $this->review_item( $query->post, $attr['element_size'] );
			}
		} else {
			$review_elements .= $this->review_no_item();
		}

		$pagination = epic_paging_navigation(
			array(
				'pagination_mode'     => 'nav_1',
				'pagination_align'    => 'center',
				'pagination_navtext'  => false,
				'pagination_pageinfo' => false,
				'total'               => $query->max_num_pages,
				'current'             => $page,
			)
		);

		$output =
			'<div class="jeg_review_search_result">
                ' . $review_elements . '
            </div>
            <div class="jeg_review_search_paging">
                ' . $pagination . '
            </div>';

		wp_reset_postdata();

		return $output;
	}

	/**
	 * Check size
	 *
	 * @param check size $attr .
	 *
	 * @return mixed
	 */
	public function check_size( $attr ) {
		if ( is_array( $attr ) ) {
			return $attr['size'];
		} elseif ( is_object( $attr ) ) {
			return $attr->size;
		} else {
			return $attr;
		}
	}

	/**
	 * Review Items
	 *
	 * @param object $post .
	 * @param string $element_size .
	 *
	 * @return string
	 */
	public function review_item( $post, $element_size ) {
		$thumbnail    = apply_filters( 'jeg_image_thumbnail', $post->ID, 'jeg-750x536' );
		$lowest_price = get_post_meta( get_the_ID(), 'epic_price_lowest', true );
		$prices       = jeg_metabox( 'epic_review_metabox.price' );
		$price_html   = '';
		$shop_html    = '';

		if ( ! $this->is_price_empty( $prices ) ) {
			foreach ( $prices as $idx => $price ) {
				if ( ! empty( $price[0] ) && ! empty( $price[1] ) ) {
					$price[1] = (int) $price[1];
					/*change this later "$price['link'] = !empty($price['link']) ? $price['link'] : '';"*/
					$icon = '';

					if ( isset( $price['icon'] ) && $price['icon'] ) {
						$shop_icon = wp_get_attachment_image_src( $price['icon'], 'full' );
						$icon      = '<img class="store-icon" src=' . $shop_icon[0] . ' alt="' . $price['shop'] . '"/>';
					}

					$shop_html .=
						'<li>
                            <a href="' . $price['link'] . '" target="_blank" class="storename">
                                ' . $icon . $price[0] . '
                            </a>
                        </li>';
				}

				if ( 2 === $idx ) {
					break;
				}
			}

			$price_html =
				'<div class="jeg_review_info">
                    <div class="price-info">
                        <h4 class="info-title">' . esc_html__( 'Best Price', 'epic-review' ) . ' : </h4>
                        <strong>' . epic_review_get_price( $lowest_price ) . '</strong>
                    </div>
                    <div class="store-info">
                        <h4 class="info-title">' . esc_html__( 'Available at', 'epic-review' ) . ' :</h4>
                        <ul>
                            ' . $shop_html . '
                        </ul>
                    </div>
                </div>';
		}

		$output =
			'<article ' . epic_post_class( 'jeg_post jeg_pl_' . $element_size, $post->ID ) . '>
                <div class="jeg_thumb">
                    ' . epic_edit_post( $post->ID ) . '
                    <a href="' . get_the_permalink( $post ) . '">' . $thumbnail . '</a>
                </div>
                <div class="jeg_postblock_content">
                    <h2 class="jeg_post_title">
                        <a href="' . get_the_permalink( $post ) . '">' . get_the_title( $post ) . '</a>
                    </h2>
                    ' . $this->post_meta( $post ) . '
                    <div class="jeg_post_excerpt">
                        <p>' . $this->get_excerpt( $post ) . '</p>
                    </div>
                </div>
                ' . $price_html . '
            </article>';

		return $output;
	}

	/**
	 * Check Price Empty
	 *
	 * @param array $prices .
	 *
	 * @return bool
	 */
	public function is_price_empty( $prices ) {
		foreach ( $prices as $price ) {
			if ( ! empty( $price['shop'] ) && ! empty( $price['price'] ) ) {
				return false;
			}
		}

		return true;
	}

	/**
	 * Post meta 1
	 *
	 * @param object  $post .
	 * @param boolean $avatar .
	 *
	 * @return string
	 */
	public function post_meta( $post, $avatar = false ) {
		$output      = '';
		$author      = $post->post_author;
		$author_url  = get_author_posts_url( $author );
		$author_name = get_the_author_meta( 'display_name', $author );
		$rating      = epic_generate_rating( $post->ID, 'jeg_landing_review' );

		$output .= '<div class="jeg_post_meta">';
		$output .= $rating;
		$output .= '<div class="jeg_meta_author"><span class="by">' . esc_html__( 'by', 'epic-review' ) . ' </span><a href="' . $author_url . '">' . $author_name . '</a></div>';
		$output .= '</div>';

		return $output;
	}

	/**
	 * Get Excerpt
	 *
	 * @param object $post .
	 *
	 * @return mixed|void
	 */
	protected function get_excerpt( $post ) {
		$excerpt = $post->post_excerpt;

		if ( empty( $excerpt ) ) {
			$excerpt = $post->post_content;
		}

		$excerpt = wp_trim_words( $excerpt, $this->excerpt_length(), $this->except_more() );
		$excerpt = preg_replace( '/\[[^\]]+\]/', '', $excerpt );

		return apply_filters( 'epic_module_excerpt', $excerpt, $post->ID, $this->excerpt_length(), $this->except_more() );
	}

	/**
	 * Excerpt Length
	 *
	 * @return int
	 */
	public function excerpt_length() {
		if ( isset( $this->attribute['excerpt_length'] ) ) {
			if ( isset( $this->attribute['excerpt_length']['size'] ) && ! empty( $this->attribute['excerpt_length']['size'] ) ) {
				return $this->attribute['excerpt_length']['size'];
			}

			return $this->attribute['excerpt_length'];
		} else {
			return 20;
		}
	}

	/**
	 * Excerpt More
	 *
	 * @return string
	 */
	public function except_more() {
		return isset( $this->attribute['excerpt_ellipsis'] ) ? $this->attribute['excerpt_ellipsis'] : ' ...';
	}

	/**
	 * No Review Found
	 *
	 * @return string
	 */
	public function review_no_item() {
		return '<div class="jeg_empty_module">' . esc_html__( 'No review found', 'epic-review' ) . '</div>';
	}

	/**
	 * Module Loader
	 *
	 * @return string
	 */
	public function module_loader() {
		$loader = get_theme_mod( 'epic_module_loader', 'dot' );
		$output =
			'<div class="module-overlay">
                <div class="preloader_type preloader_{$loader}">
                    <div class="module-preloader jeg_preloader dot">
                        <span></span><span></span><span></span>
                    </div>
                    <div class="module-preloader jeg_preloader circle">
                        <div class="epic_preloader_circle_outer">
                            <div class="epic_preloader_circle_inner"></div>
                        </div>
                    </div>
                    <div class="module-preloader jeg_preloader square">
                        <div class="jeg_square"><div class="jeg_square_inner"></div></div>
                    </div>
                </div>
            </div>';

		return $output;
	}

	/**
	 * Inherit Parent
	 *
	 * @param string $result .
	 * @param array $attr .
	 */
	public function render_result_element( $result, $attr ) {
	}
}
