<?php
/**
 * Epic Review Metabox
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Metabox
 *
 * @package Epic\Review\Metabox
 */
class Metabox {
	/**
	 * Metabox instance variable
	 *
	 * @var Metabox
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		if ( is_admin() ) {
			add_action( 'plugins_loaded', array( $this, 'initialize_metabox' ) );
		}
	}

	/**
	 * Metabox instance function
	 *
	 * @return Metabox
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Initialize Metabox
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = array(
			'id'        => 'epic_review_metabox',
			'title'     => esc_html__( 'Epic Review', 'epic-review' ),
			'post_type' => 'post',
			'type'      => 'tabbed',
			'segments'  => $segments,
			'fields'    => $fields,
		);

		new Form_Meta_Box( $option );
	}

	/**
	 * Initialize metabox segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = array();

		$segments['review_setting'] = array(
			'name'     => esc_html__( 'Review Setting', 'epic-review' ),
			'priority' => 1,
		);

		$segments['review_pros_cons'] = array(
			'name'     => esc_html__( 'Review Pros and Cons', 'epic-review' ),
			'priority' => 1,
		);

		$segments['review_rating'] = array(
			'name'     => esc_html__( 'Review Rating', 'epic-review' ),
			'priority' => 1,
		);

		$segments['review_price'] = array(
			'name'     => esc_html__( 'Product Price', 'epic-review' ),
			'priority' => 1,
		);

		return $segments;
	}

	/**
	 * Initialize metabox fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = array();

		/* Review Setting */
		$fields['enable_review'] = array(
			'type'        => 'checkbox',
			'segment'     => 'review_setting',
			'title'       => esc_html__( 'Enable Review', 'epic-review' ),
			'description' => esc_html__( 'Check this option to enable review on this post.', 'epic-review' ),
		);

		$fields['type'] = array(
			'type'        => 'select',
			'segment'     => 'review_setting',
			'title'       => esc_html__( 'Review Type', 'epic-review' ),
			'description' => esc_html__( 'Choose your review type.', 'epic-review' ),
			'default'     => 'percentage',
			'options'     => array(
				'point'      => esc_html__( 'Point', 'epic-review' ),
				'star'       => esc_html__( 'Star', 'epic-review' ),
				'percentage' => esc_html__( 'Percentage', 'epic-review' ),
			),
		);

		$fields['name'] = array(
			'type'        => 'text',
			'segment'     => 'review_setting',
			'title'       => esc_html__( 'Review Product Name', 'epic-review' ),
			'description' => esc_html__( 'Your review product name.', 'epic-review' ),
		);

		$fields['summary'] = array(
			'type'        => 'text',
			'segment'     => 'review_setting',
			'title'       => esc_html__( 'Review Summary', 'epic-review' ),
			'description' => esc_html__( 'Insert your review summary.', 'epic-review' ),
		);

		/* Review Pros Cons */
		$fields['good'] = array(
			'type'      => 'repeater',
			'segment'   => 'review_pros_cons',
			'title'     => esc_html__( 'What\'s good about this product', 'epic-review' ),
			'default'   => array(),
			'choices'   => array(
				'limit' => '',
			),
			'row_label' => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Point', 'epic-review' ),
				'field' => false,
			),
			'fields'    => array(
				'value' => array(
					'type'        => 'text',
					'name'        => 'good_text',
					'description' => esc_html__( 'Insert the good thing about this product.', 'epic-review' ),
				),
			),
		);

		$fields['bad'] = array(
			'type'      => 'repeater',
			'segment'   => 'review_pros_cons',
			'title'     => esc_html__( 'What\'s bad about this product', 'epic-review' ),
			'default'   => array(),
			'choices'   => array(
				'limit' => '',
			),
			'row_label' => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Point', 'epic-review' ),
				'field' => false,
			),
			'fields'    => array(
				'value' => array(
					'type'        => 'text',
					'name'        => 'bad_text',
					'description' => esc_html__( 'Insert the bad thing about this product.', 'epic-review' ),
				),
			),
		);

		/* Review Rating */
		$fields['rating'] = array(
			'type'      => 'repeater',
			'segment'   => 'review_rating',
			'title'     => esc_html__( 'Review Rating', 'epic-review' ),
			'default'   => array(),
			'choices'   => array(
				'limit' => '',
			),
			'row_label' => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Rating', 'epic-review' ),
				'field' => false,
			),
			'fields'    => array(
				'label' => array(
					'type'        => 'text',
					'name'        => 'rating_text',
					'description' => esc_html__( 'Insert text for rating label.', 'epic-review' ),
				),
				'value' => array(
					'type'        => 'slider',
					'name'        => 'rating_number',
					'description' => esc_html__( 'Set rating value.', 'epic-review' ),
					'options'     => array(
						'min'  => 1,
						'max'  => 10,
						'step' => 1,
					),
					'default'     => 10,
				),
			),
		);

		/* Review Price */
		$fields['price'] = array(
			'type'      => 'repeater',
			'segment'   => 'review_price',
			'title'     => esc_html__( 'Product Price', 'epic-review' ),
			'default'   => array(),
			'choices'   => array(
				'limit' => '',
			),
			'row_label' => array(
				'type'  => 'text',
				'value' => esc_attr__( 'Price', 'epic-review' ),
				'field' => false,
			),
			'fields'    => array(
				'shop'  => array(
					'type'        => 'text',
					'name'        => 'shop',
					'description' => esc_html__( 'Where to Buy. example : Amazon, Ebay.', 'epic-review' ),
				),
				'value' => array(
					'type'        => 'text',
					'name'        => 'price',
					'description' => esc_html__( 'Insert product price.', 'epic-review' ),
				),
				'link'  => array(
					'type'        => 'text',
					'name'        => 'link',
					'description' => esc_html__( 'Insert the shop link or you can also insert your referral link.', 'epic-review' ),
				),
				/* array(
			'type'         => 'image',
			'name'         => 'icon',
			'description'  => esc_html__('Upload this shop logo / icon 16x16 pixel', 'epic-review'),
			), */
			),
		);

		return $fields;
	}
}
