<?php


namespace Epic\Review\Widget;

use Epic\Review\Data\SingleData;
use Epic\Review\Widget\Widget_Base;

/**
 * Class Review_List_Widget
 *
 * @package Epic\Review\Widget
 */
class Review_Single_Widget extends Widget_Base {
	/**
	 * Review_List_Widget constructor.
	 */
	public function __construct() {
		parent::__construct(
			'epic_review_single',
			esc_html__( 'Epic - Review Single', 'epic-review' ),
			[
				'description'                 => esc_html__( 'Single Post Review widget for your website', 'epic-review' ),
				'customize_selective_refresh' => true,
			],
			null
		);
		add_filter( 'dynamic_sidebar_params', [ $this, 'widget_class' ], 10, 1 );
	}

	/**
	 * Register widget with WordPress.
	 *
	 * @param - $instance .
	 */
	public function form( $instance ) {
		$options = [
			'title'                 => [
				'title' => esc_html__( 'Title', 'epic-review' ),
				'desc'  => esc_html__( 'Title on widget header.', 'epic-review' ),
				'type'  => 'text',
				'group' => 'general-setting',
			],
			'review_show_rating'    => [
				'type'  => 'checkbox',
				'title' => esc_html__( 'Show Rating *', 'epic-review' ),
				'group' => 'general-setting',
			],
			'review_show_pros_cons' => [
				'type'  => 'checkbox',
				'title' => esc_html__( 'Show Pros and Cons *', 'epic-review' ),
				'group' => 'general-setting',
			],
			'review_show_breakdown' => [
				'type'  => 'checkbox',
				'title' => esc_html__( 'Show Review Breakdown *', 'epic-review' ),
				'group' => 'general-setting',
			],
			'review_show_price'     => [
				'type'  => 'checkbox',
				'title' => esc_html__( 'Show Price *', 'epic-review' ),
				'desc'  => esc_html__( '* This widget only work for sidebar in single post.', 'epic-review' ),
				'group' => 'general-setting',
			],
		];

		$this->render_widget_form( $instance, $options );
	}

	/**
	 * Front-end display of widget.
	 *
	 * @param array $args Widget arguments.
	 * @param array $instance Saved values from database.
	 *
	 * @see WP_Widget::widget()
	 */
	public function widget( $args, $instance ) {
		if ( is_single() ) {
			$title = apply_filters( 'widget_title', isset( $instance['title'] ) ? $instance['title'] : '' );

			sanitize_review( $args['before_widget'] );

			if ( ! empty( $title ) ) {
				sanitize_review( $args['before_title'] . esc_html( $title ) . $args['after_title'] );
			}

			$post_id     = get_the_ID();
			$single_data = new SingleData( 'element', $post_id, $instance );

			$output = $single_data->single_review_template( true );
			sanitize_review( $output );

			sanitize_review( $args['after_widget'] );
		}
	}


	/**
	 * Check the widget options before it's wrapper loads to add classes
	 *
	 * @param - $params .
	 *
	 * @return array
	 */
	public function widget_class( $params ) {
		return $this->add_widget_classes( $params, 'epic_review_single' );
	}
}
