<?php
/**
 * Epic Review Widget
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Widget;

use Jeg\Form\Form_Widget;
use Jetpack;

/**
 * Class WidgetBase
 *
 * @package Epic\Review\Widget
 */
class Widget_Additional {
	/**
	 * WidgetBase instance
	 *
	 * @var Widget_Base
	 */
	private static $instance;

	/**
	 * WidgetBase constructor.
	 */
	private function __construct() {
		if ( is_admin() ) {
			if ( ! is_customize_preview() ) {
				add_action( 'in_widget_form', [ $this, 'additional_form' ], null, 3 );
			}
			add_filter( 'widget_update_callback', [ $this, 'update_widget_form' ], 99, 2 );
		}
	}

	/**
	 * WidgetBase
	 *
	 * @return Widget_Base
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Return new instance instead older instance
	 *
	 * @param - $instance .
	 * @param - $new_instance .
	 *
	 * @return array
	 */
	public function update_widget_form( $instance, $new_instance ) {
		if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'widget-visibility' ) || defined( 'POLYLANG_VERSION' ) || defined( 'ICL_SITEPRESS_VERSION' ) ) {
			return array_merge( $instance, $new_instance );
		}

		return $new_instance;
	}

	/**
	 * Unique id
	 *
	 * @return string
	 */
	public function unique_id() {
		return uniqid();
	}

	/**
	 * Additional Form
	 *
	 * @param - $t \WP_Widget .
	 * @param - $return .
	 * @param - $instance .
	 */
	public function additional_form( $t, $return, $instance ) {
		if ( strpos( $t->id_base, 'epic_' ) === false ) {
			$id       = $t->get_field_id( 'widget_news_element' );
			$segments = $this->prepare_segments();
			$fields   = $this->prepare_fields( $t, $instance );

			/*if ( class_exists( 'Jeg\Form\Form_Widget' ) ) {
				Form_Widget::render_form( $id, $segments, $fields );
			}*/
		}
	}

	/**
	 * Prepare segments
	 *
	 * @return array
	 */
	public function prepare_segments() {
		$segments = [];
		$priority = 1;
		$options  = $this->header_form();

		foreach ( $options as $key => $item ) {
			$id = sanitize_title_with_dashes( $key );

			if ( ! isset( $segments[ $id ] ) ) {
				$segments[ $id ] = [
					'id'       => $id,
					'type'     => 'default',
					'name'     => $key,
					'priority' => $priority ++,
				];
			}
		}

		return $segments;
	}

	public function header_form() {
		return [
			esc_html__( 'Header Settings', 'epic-review' )   => [
				'second_title' => [
					'type'    => 'text',
					'title'   => esc_html__( 'Second Title', 'epic-review' ),
					'desc'    => esc_html__( 'Secondary title of Widget.', 'epic-review' ),
					'default' => '',
					'options' => '',
					'name'    => 'second_title',
					'group'   => 'header-settings',
				],

				'header_url' => [
					'type'    => 'text',
					'title'   => esc_html__( 'Title URL', 'epic-review' ),
					'desc'    => esc_html__( 'Insert URL for heading title.', 'epic-review' ),
					'default' => '',
					'options' => '',
					'name'    => 'header_url',
					'group'   => 'header-settings',
				],

				'header_type' => [
					'type'    => 'radioimage',
					'title'   => esc_html__( 'Header Type', 'epic-review' ),
					'desc'    => esc_html__( 'Choose which header type fit with your content design.', 'epic-review' ),
					'default' => 'heading_6',
					'options' => [
						'heading_1' => JEG_THEME_URL . '/assets/img/admin/heading-1.png',
						'heading_2' => JEG_THEME_URL . '/assets/img/admin/heading-2.png',
						'heading_3' => JEG_THEME_URL . '/assets/img/admin/heading-3.png',
						'heading_4' => JEG_THEME_URL . '/assets/img/admin/heading-4.png',
						'heading_6' => JEG_THEME_URL . '/assets/img/admin/heading-6.png',
						'heading_7' => JEG_THEME_URL . '/assets/img/admin/heading-7.png',
						'heading_8' => JEG_THEME_URL . '/assets/img/admin/heading-8.png',
						'heading_9' => JEG_THEME_URL . '/assets/img/admin/heading-9.png',
					],
					'name'    => 'header_type',
					'group'   => 'header-settings',
				],

				'header_background' => [
					'type'    => 'color',
					'title'   => esc_html__( 'Header Background', 'epic-review' ),
					'desc'    => esc_html__( 'This option may not work for all of heading type.', 'epic-review' ),
					'default' => '',
					'options' => '',
					'name'    => 'header_background',
					'group'   => 'header-settings',
				],

				'header_text_color' => [
					'type'    => 'color',
					'title'   => esc_html__( 'Header Text Color', 'epic-review' ),
					'desc'    => esc_html__( 'This option may not work for all of heading type.', 'epic-review' ),
					'default' => '',
					'options' => '',
					'name'    => 'header_text_color',
					'group'   => 'header-settings',
				],
			],
			esc_html__( 'Advanced Settings', 'epic-review' ) => [
				'widget_boxed'  => [
					'type'    => 'checkbox',
					'title'   => esc_html__( 'Enable Boxed', 'epic-review' ),
					'desc'    => esc_html__( 'Enable boxed for this widget.', 'epic-review' ),
					'default' => false,
					'name'    => 'widget_boxed',
					'group'   => 'advanced-settings',
				],
				'widget_shadow' => [
					'type'       => 'checkbox',
					'title'      => esc_html__( 'Enable Shadow', 'epic-review' ),
					'desc'       => esc_html__( 'Enable shadow for this widget.', 'epic-review' ),
					'default'    => false,
					'name'       => 'widget_shadow',
					'dependency' => [
						[
							'field'    => 'widget_boxed',
							'operator' => '==',
							'value'    => true,
						],
					],
					'group'      => 'advanced-settings',
				],
				'widget_class'  => [
					'type'    => 'text',
					'title'   => esc_html__( 'Extra class name', 'epic-review' ),
					'desc'    => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'epic-review' ),
					'default' => '',
					'options' => '',
					'name'    => 'widget_class',
					'group'   => 'advanced-settings',
				],
			],
		];
	}

	/**
	 * Prepare Fields
	 *
	 * @param - $t .
	 * @param - $instance .
	 *
	 * @return array
	 */
	public function prepare_fields( $t, $instance ) {
		$setting = [];
		$fields  = $this->header_form();

		foreach ( $fields as $field ) {
			foreach ( $field as $key => $item ) {
				$setting[ $key ]                = [];
				$setting[ $key ]['id']          = $key;
				$setting[ $key ]['fieldID']     = $t->get_field_id( $key );
				$setting[ $key ]['fieldName']   = $t->get_field_name( $key );
				$setting[ $key ]['type']        = $item['type'];
				$setting[ $key ]['title']       = isset( $item['title'] ) ? $item['title'] : '';
				$setting[ $key ]['description'] = isset( $item['desc'] ) ? $item['desc'] : '';
				$setting[ $key ]['segment']     = isset( $item['group'] ) ? sanitize_title_with_dashes( $item['group'] ) : '';
				$setting[ $key ]['default']     = isset( $item['default'] ) ? $item['default'] : '';
				$setting[ $key ]['priority']    = isset( $item['priority'] ) ? $item['priority'] : 10;
				$setting[ $key ]['options']     = isset( $item['options'] ) ? $item['options'] : [];
				$setting[ $key ]['multiple']    = isset( $item['multiple'] ) ? $item['multiple'] : 1;
				$setting[ $key ]['ajax']        = isset( $item['ajax'] ) ? $item['ajax'] : '';
				$setting[ $key ]['nonce']       = isset( $item['nonce'] ) ? $item['nonce'] : '';
				$setting[ $key ]['value']       = $this->get_value( $key, $instance, $setting[ $key ]['default'] );
				$setting[ $key ]['fields']      = isset( $item['fields'] ) ? $item['fields'] : [];
				$setting[ $key ]['row_label']   = isset( $item['row_label'] ) ? $item['row_label'] : [];
				$setting[ $key ]['dependency']  = isset( $item['dependency'] ) ? $item['dependency'] : '';
			}
		}

		return $setting;
	}

	/**
	 * Get value
	 *
	 * @param - $id .
	 * @param - $value .
	 * @param - $default .
	 *
	 * @return mixed
	 */
	public function get_value( $id, $value, $default ) {
		if ( isset( $value[ $id ] ) ) {
			return $value[ $id ];
		} else {
			return $default;
		}
	}
}

