<?php
/**
 * Epic Review Widget
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package epic-review
 */

namespace Epic\Review\Widget;

use Jeg\Form\Form_Widget;
use WP_Widget;

/**
 * Class WidgetBase
 *
 * @package Epic\Review\Widget
 */
class Widget_Base extends WP_Widget {
	/**
	 * Render the widget form
	 *
	 * @param - $instance .
	 * @param - $options .
	 */
	public function render_widget_form( $instance, $options ) {
		if ( ! is_customize_preview() ) {
			$id = $this->get_field_id( 'widget_news_element' );

			$segments[] = [
				'id'   => 'general-setting',
				'name' => esc_html__( 'General Setting', 'epic-review' ),
			];

			$fields = $this->prepare_fields( $instance, $options );

			// TODO : Add additional widget options later

			$additional_instance = Widget_Additional::instance();
			$additional_field    = $additional_instance->prepare_fields( $this, $instance );
			$additional_segment  = $additional_instance->prepare_segments();

			if ( class_exists( 'Jeg\Form\Form_Widget' ) ) {
				Form_Widget::render_form( $id, array_merge( $segments, $additional_segment ), array_merge( $fields, $additional_field ) );
				//Form_Widget::render_form( $id, $segments, $fields );
			}
		}
	}

	/**
	 * Prepare Fields
	 *
	 * @param - $instance .
	 * @param - $options .
	 *
	 * @return array
	 */
	public function prepare_fields( $instance, $options ) {
		$setting = [];
		$fields  = $options;

		foreach ( $fields as $key => $field ) {

			$setting[ $key ]              = [];
			$setting[ $key ]['id']        = $key;
			$setting[ $key ]['fieldID']   = $this->get_field_id( $key );
			$setting[ $key ]['fieldName'] = $this->get_field_name( $key );
			$setting[ $key ]['type']      = $field['type'];

			$setting[ $key ]['title']       = isset( $field['title'] ) ? $field['title'] : '';
			$setting[ $key ]['description'] = isset( $field['desc'] ) ? $field['desc'] : '';
			$setting[ $key ]['segment']     = isset( $field['group'] ) ? $field['group'] : '';
			$setting[ $key ]['default']     = isset( $field['default'] ) ? $field['default'] : '';
			$setting[ $key ]['priority']    = isset( $field['priority'] ) ? $field['priority'] : 10;
			$setting[ $key ]['options']     = isset( $field['options'] ) ? $field['options'] : [];
			$setting[ $key ]['dependency']  = isset( $field['dependency'] ) ? $field['dependency'] : '';
			$setting[ $key ]['multiple']    = isset( $field['multiple'] ) ? $field['multiple'] : 1;
			$setting[ $key ]['ajax']        = isset( $field['ajax'] ) ? $field['ajax'] : '';
			$setting[ $key ]['nonce']       = isset( $field['nonce'] ) ? $field['nonce'] : '';
			$setting[ $key ]['choices']     = isset( $field['choices'] ) ? $field['choices'] : '';
			$setting[ $key ]['value']       = $this->get_value( $key, $instance, $setting[ $key ]['default'] );
			$setting[ $key ]['fields']      = isset( $field['fields'] ) ? $field['fields'] : [];
			$setting[ $key ]['row_label']   = isset( $field['row_label'] ) ? $field['row_label'] : [];

			if ( 'image' === $setting[ $key ]['type'] ) {
				$image = wp_get_attachment_image_src( $setting[ $key ]['value'], 'full' );
				if ( isset( $image[0] ) ) {
					$setting[ $key ]['imageUrl'] = $image[0];
				}
			}
		}

		return $setting;
	}

	/**
	 * Get Value
	 *
	 * @param - $id .
	 * @param - $value .
	 * @param - $default .
	 *
	 * @return mixed
	 */
	public function get_value( $id, $value, $default ) {
		if ( isset( $value[ $id ] ) ) {
			return $value[ $id ];
		} else {
			return $default;
		}
	}

	/**
	 * Add widget classes
	 *
	 * @param - $params .
	 * @param - $widget_id .
	 *
	 * @return mixed
	 */
	public function add_widget_classes( $params, $widget_id ) {
		global $wp_registered_widgets;
		$id = $params[0]['widget_id'];

		if ( isset( $wp_registered_widgets[ $id ]['callback'][0] ) && is_object( $wp_registered_widgets[ $id ]['callback'][0] ) && strpos( $params[0]['widget_id'], $widget_id ) !== false ) {
			$callback         = $wp_registered_widgets[ $id ]['callback'][0];
			$settings         = $callback->get_settings();
			$setting_key      = substr( $id, strrpos( $id, '-' ) + 1 );
			$instance         = isset( $settings[ $setting_key ] ) ? $settings[ $setting_key ] : [];
			$unique_class     = 'jeg_' . uniqid();
			$additional_class = '';

			$heading                   = ! empty( $instance['header_type'] ) ? $instance['header_type'] : 'heading_6';
			$params[0]['before_title'] = "<div class=\"jeg_block_heading jeg_block_{$heading} {$unique_class}\"><h3 class=\"jeg_block_title\">";

			$second = ! empty( $instance['second_title'] ) ? '<strong>' . $instance['second_title'] . '</strong>' : '';

			if ( ! empty( $instance['header_url'] ) ) {
				$params[0]['before_title'] .= '<a href="' . $instance['header_url'] . '"><span>';
				$params[0]['after_title']   = $second . '</span></a></h3></div>';
			} else {
				$params[0]['before_title'] .= '<span>';
				$params[0]['after_title']   = $second . '</span></h3></div>';
			}

			$header_styling            = epic_header_styling( $instance, $unique_class );
			$params[0]['after_title'] .= ! empty( $header_styling ) ? '<style scoped>' . $header_styling . '</style>' : '';

			if ( isset( $instance['widget_class'] ) ) {
				$additional_class .= $instance['widget_class'];
			}
			if ( isset( $instance['widget_boxed'] ) && $instance['widget_boxed'] ) {
				$additional_class .= ' jeg_pb_boxed';
			}
			if ( isset( $instance['widget_shadow'] ) && $instance['widget_shadow'] ) {
				$additional_class .= ' jeg_pb_boxed_shadow';
			}
			if ( ! empty( $additional_class ) ) {
				$params[0]['before_widget'] = preg_replace( '/widget/', 'widget ' . $additional_class, $params[0]['before_widget'], 1 );
			}
		}

		return $params;
	}
}

